@@ -1,14 +1,20 @@
+use std::error::Error;
 use std::fmt;
 
 /// Type which returns a Result with a type of T and Error an type of EmptyVecErr
-pub type ErrResult<T> = std::result::Result<T, EmptyVecErr>;
+pub type ErrResult<T> = std::result::Result<T, Box<dyn Error>>;
 
 /// Error which shows up when no transactions have happened in a Blockchain
 #[derive(Debug, Clone)]
 pub struct EmptyVecErr;
 
+impl Error for EmptyVecErr {}
+
 impl fmt::Display for EmptyVecErr {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(f, "No transactions have happened!")
+        write!(
+            f,
+            "\x1b[31m\x1b[1mError: No transactions have happened!\x1b[0m"
+        )
     }
 }
